# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:clusteraddress, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::IPFQDN

  desc <<-DESC
  The address that forms a portion of the URL a client uses to connect to this cluster, and that is used for generating EJB handles and entity EJB failover addresses. (This address may be either a DNS host name that maps to multiple IP addresses or an array of single address host names or IP addresses.)  Defines the address to be used by clients to connect to this cluster. This address may be either a DNS host name that maps to multiple IP addresses or a comma separated list of single address host names or IP addresses. If network channels are configured, it is possible to set the cluster address on a per channel basis.

  An example on how to use this:

        wls_cluster { 'aCluster':
          ...
          clusteraddress => '10.10.10.30',
          ...
        }

    or use a host name like this:

        wls_cluster { 'aCluster':
          ...
          clusteraddress => 'myhost.exaqmple.com',
          ...
        }

  DESC

  data_type('Optional[String]')

  maps_to('ClusterAddress')
end
