# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:additional_auto_migration_attempts, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  A migratable server could fail to come up on every possible configured machine. This attribute controls how many further attempts, after the first one, should be tried.  Note that each attempt specified here indicates another full circuit of migrations amongst all the configured machines. So for a 3-server cluster, and the default value of 3, a total of 9 migrations will be attempted.  If it is set to -1, migrations will go on forever until the server starts.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         additional_auto_migration_attempts => '3'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:additional_auto_migration_attempts']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('AdditionalAutoMigrationAttempts')
end
