# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_checkpoint_interval_seconds, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The interval at which the transaction manager creates a new transaction log file and checks all old transaction log files to see if they are ready to be deleted.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         jta_checkpoint_interval_seconds => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:jta_checkpoint_interval_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JTACluster/%<cluster_name>s/CheckpointIntervalSeconds')
end
