# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_determiners, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies a list of one or more transaction resources (determiners) separated by line breaks. A determiner's in-doubt transaction records are used during transaction recovery when a TLog is not present.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         jta_determiners => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:jta_determiners']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JTACluster/%<cluster_name>s/Determiners')
end
