# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_unregister_resource_grace_period, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The amount of time, in seconds, a  transaction manager waits for transactions involving the resource to complete before unregistering a resource. This grace period helps minimize the risk of abandoned transactions because of an unregistered resource, such as a JDBC data source module packaged with an application.  During the specified grace period, the <code>unregisterResource</code> call blocks until the call returns and no new transactions are started for the associated resource. If the number of outstanding transactions for the resource goes to <code>0</code>, the <code>unregisterResource</code> call returns immediately.  At the end of the grace period, if outstanding transactions are associated with the resource, the <code>unregisterResource</code> call returns and a log message is written to the server on which the resource was previously registered.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         jta_unregister_resource_grace_period => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:jta_unregister_resource_grace_period']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JTACluster/%<cluster_name>s/UnregisterResourceGracePeriod')
end
