# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:session_flush_interval, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Interval in seconds until HTTP Sessions are periodically flushed to the backup cluster to dump session state on disk.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         session_flush_interval => '180'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:session_flush_interval']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('SessionFlushInterval')
end
