# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:session_lazy_deserialization_enabled, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Enables increased efficiency with session replication. Enabling this attribute should be used only when configuring a WebLogic domain for Oracle Exalogic.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         session_lazy_deserialization_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:session_lazy_deserialization_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('SessionLazyDeserializationEnabled')
end
