# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:weblogic_plugin_enabled, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Specifies whether the proprietary <tt>WL-Proxy-Client-IP</tt> header should be used. (This needed only when WebLogic plugins are configured.)  Gets the weblogicPluginEnabled attribute of the ClusterMBean object

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         weblogic_plugin_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:weblogic_plugin_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('WeblogicPluginEnabled')
end
