# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:frontendhost, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::IPFQDN

  desc <<-DESC
  The name of the host to which all redirected URLs will be sent.  Sets the HTTP FrontendHost for the default webserver (not virtual hosts) for all the servers in the cluster. Provides a method to ensure that the webapp will always have the correct HOST information, even when the request is coming through a firewall or a proxy. If this parameter is configured, the HOST header will be ignored and the information in this parameter will be used in its place, when constructing the absolute urls for redirects.

  Here is an example on how to use this:

      wls_cluster { 'aCluster':
        ...
        frontendhost => '10.10.10.30',
        ...
      }

  or use a host name like this:

      wls_cluster { 'aCluster':
        ...
        frontendhost => 'myhost.exaqmple.com',
        ...
      }
  DESC

  data_type('Optional[String]')

  maps_to('FrontendHost')
end
