# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:migrationbasis, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC

  Controls the mechanism used for server and service migration. <ul> <li>Database -- Requires the availability of a high-availability database, such as Oracle RAC, to store leasing information. <li>Consensus -- Stores the leasing information in-memory within a cluster member. This option requires Node Manager to be configured and running. </ul> Note: Within a WebLogic Server installation, you can only use one type of leasing. Although it is possible to implement multiple features that use leasing within your environment, each must use the same kind of leasing.

  Here is an example on how to use this:

      wls_cluster { 'aCluster':
        ...
        migrationbasis => 'database',
        ...
      }

  DESC

  newvalues('absent', 'consensus', 'database')

  maps_to('MigrationBasis')
  #
  # TODO: Look at the other code in modify
  #
  data_type("Optional[Enum['absent', 'consensus','database']]")
end
