# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:securereplication, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Servers in a cluster replicate session data. If a replication channel is defined then the session data will be sent using the replication channel protocol and secured replication settings will be ignored. If no replication channel is defined and secured replication is enabled then session data for in-memory replication will be sent over SSL using the default secured channel. However, this added security for replication traffic comes with a significant cluster performance degradation. It should only be enabled if security is of greater concern than performance degradation.

  Here is an example on how to use this:
      wls_cluster { 'aCluster':
        ...
        securereplication => 1,
        ...
      }

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('SecureReplicationEnabled')
end
