# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:start_mw_home, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The MWHome directory (path on the machine running Node Manager) to use when starting this server.  Specify the directory on the Node Manager machine under which all of Oracle's MW products were installed. For example, <code>c:&#92;Oracle&#92;Middleware&#92;</code>.

  An example on how to use this:

      wls_coherence_server {a_wls_coherence_server :
         ...
         start_mw_home => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_coherence_server:start_mw_home']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('CoherenceServerStart/%<coherence_server_name>s/MWHome')
end
