# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ds_jndi_names, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The JNDI path to where this Data Source is bound. By default, the JNDI name is the name of the data source.  Applications that look up the JNDI path will get a <code>javax.sql.DataSource</code> instance that corresponds to this data source.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         ds_jndi_names => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:ds_jndi_names']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<datasource_name>s/JDBCDataSourceParams/%<datasource_name>s/JNDINames')
end
