# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_min_capacity, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The minimum number of physical connections that this connection pool can contain after it is initialized.

  - Default: `InitialCapacity`
  - Used only for connection pool shrinking calculations.
  - For compatibility, `InitialCapacity` is used if `MinCapacity` is not configured.
  - Once a data source has gone through a suspend/resume, the larger value of either `MinCapacity` or `InitialCapacity` is used.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         pool_min_capacity => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:pool_min_capacity']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/MinCapacity')
end
