# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_profile_type, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies that type of profile data to be collected for the JDBC subsystem.  You can specify combinations of the following profile types:  <ul> <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_USAGE - Profile threads currently using connections from the pool of connections in the data source. </li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_RESV_WAIT - Profile threads currently waiting to reserve a connection from the data source.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_LEAK - Profile threads that have reserved a connection from the data source and the connection leaked (was not properly returned to the pool of connections).</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_RESV_FAIL - Profile threads that attempt to reserve a connection from the data source but fail.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_STMT_CACHE_ENTRY - Profile prepared and callable statements added to the statement cache, and profile the threads that originated the cached statements.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_STMT_USAGE - Profile threads currently executing SQL statements from the statement cache.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_LAST_USAGE - Profile the previous thread that last used the connection. This information is useful when debugging problems with connections infected with pending transactions that cause subsequent XA operations on the connections to fail.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_CONN_MT_USAGE - Profile threads that erroneously use a connection previously obtained by a different thread.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_NONE - Disable profiling for the data source.</li>  <li>weblogic.jdbc.common.internal.JDBCConstants.PROFILE_TYPE_ALL - Enable all profile types for the data source.</li>  </ul>

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         pool_profile_type => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:pool_profile_type']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/ProfileType')
end
