# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xa_new_xa_conn_for_commit, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Specifies that a dedicated XA connection is used for commit and rollback processing for a global transaction.  Only applies to data sources that use an XA driver.  Use this setting to work around specific problems with JDBC XA drivers.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         xa_new_xa_conn_for_commit => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:xa_new_xa_conn_for_commit']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCXAParams/%<datasource_name>s/NewXaConnForCommit')
end
