# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jpa_default_jpa_provider, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  The configured default JPA provider for the domain.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jpa_default_jpa_provider => 'org.eclipse.persistence.jpa.PersistenceProvider'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jpa_default_jpa_provider']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JPA/%<domain_name>s/DefaultJPAProvider')
end
