# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_log4j_logging_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Specifies whether the server logging is based on a Log4j implementation. By default, WebLogic logging uses an implementation based on the Java Logging APIs which are part of the JDK.  Applications that use the WebLogic Message Catalog framework or the NonCatalogLogger will not be affected by the underlying Logging implementation.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         log_log4j_logging_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:log_log4j_logging_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('Log/%<domain_name>s/Log4jLoggingEnabled')
end
