# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_credential, :parent => Puppet::Parameter::WlsEncryptedProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  The password for the domain. In WebLogic Server version 6.0, this attribute was the password of the system user. In WebLogic Server version 7.0, this attribute can be any string. For the two domains to interoperate, the string must be the same for both domains.  When you set the value of this attribute, WebLogic Server does the following: <ol><li>Encrypts the value.</li> <li>Sets the value of the <code>UserPasswordEncrypted</code> attribute to the encrypted value.</li> </ol>

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_credential => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_credential']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('SecurityConfiguration/%<domain_name>s/Credential')
end
