# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:calculated_machine_names, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The CalculatedMachineNames attribute controls how server instances in a dynamic cluster are assigned to a machine. If the attribute is not set, then the dynamic servers will not be assigned to a machine. If the attribute is set, then the MachineNameMatchExpression attribute is used to select the set of machines to use for the dynamic servers.

  An example on how to use this:

      wls_dynamic_cluster {a_wls_dynamic_cluster :
         ...
         calculated_machine_names => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_dynamic_cluster:calculated_machine_names']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")
  maps_to('CalculatedMachineNames')
end
