# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:cache_directory, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The location of the cache directory for `Direct-Write-With-Cache`, ignored for other policies.  When `Direct-Write-With-Cache` is specified as the `SynchronousWritePolicy`, cache files are created in addition to primary files (see <a href='#getDirectory'>Directory for the location of primary files)</a>. If a cache directory location is specified, the cache file path is `CacheDirectory/WLStoreCache/StoreNameFileNum.DAT.cache`. When specified, Oracle recommends using absolute paths, but if the directory location is a relative path, then `CacheDirectory` is created relative to the WebLogic Server instance's home directory. If "" or `Null` is specified, the `Cache Directory` is located in the current operating system `temp` directory as determined by the `java.io.tmpdir` Java System property (JDK's default: `/tmp` on UNIX, `%TEMP% ` on Windows) and is ` TempDirectory/WLStoreCache/DomainName/unique-id/StoreNameFileNum.DAT.cache`. The value of `java.io.tmpdir` varies between operating systems and configurations, and can be overridden by passing `-Djava.io.tmpdir=My_path` on the JVM command line.   Considerations:

  - Security: Some users may want to set specific directory permissions to limit access to the cache directory, especially if there are custom configured user access limitations on the primary directory. For a complete guide to WebLogic security, see "Securing a Production Environment for Oracle WebLogic Server."
  - Additional Disk Space Usage: Cache files consume the same amount of disk space as the primary store files that they mirror. See <a href='#getDirectory'>Directory for the location of primary store files</a>.
  - Performance: For the best performance, a cache directory should be located in local storage instead of NAS/SAN (remote) storage, preferably in the operating system's `temp` directory. Relative paths should be avoided, as relative paths are located based on the domain installation, which is typically on remote storage. It is safe to delete a cache directory while the store is not running, but this may slow down the next store boot.
  - Preventing Corruption and File Locking: Two same named stores must not be configured to share the same primary or cache directory. There are store file locking checks that are designed to detect such conflicts and prevent corruption by failing the store boot, but it is not recommended to depend on the file locking feature for correctness. See <a href='#isFileLockingEnabled'>Enable File Locking.</a>
  - Boot Recovery: Cache files are reused to speed up the File Store boot and recovery process, but only if the store's host WebLogic Server instance has been shut down cleanly prior to the current boot. For example, cache files are not re-used and are instead fully recreated: after a `kill -9`, after an OS or JVM crash, or after an off-line change to the primary files, such as a store admin compaction. When cache files are recreated, a `Warning` log message 280102 is generated.
  - Fail-Over/Migration Recovery: A file store safely recovers its data without its cache directory. Therefore, a cache directory does not need to be copied or otherwise made accessible after a fail-over or migration, and similarly does not need to be placed in NAS/SAN storage. A `Warning` log message 280102, which is generated to indicate the need to recreate the cache on the new host system, can be ignored.
  - Cache File Cleanup: To prevent unused cache files from consuming disk space, test and developer environments should periodically delete cache files.

  An example on how to use this:

      wls_file_persistence_store {a_wls_file_persistence_store :
         ...
         cache_directory => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_file_persistence_store:cache_directory']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('CacheDirectory')
end
