# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:properties, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Any additional properties that must be set for the JNDI provider. These properties will be passed directly to the constructor for the JNDI provider's <tt>InitialContext</tt> class.  Note: This value must be filled in using a <tt>name=value&lt;return&gt;name=value</tt> format.

  An example on how to use this:

      wls_foreign_jndi_provider {a_wls_foreign_jndi_provider :
         ...
         properties => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_foreign_jndi_provider:properties']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('Properties')
end
