# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:data_source, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The JDBC data source used by this JDBC store to access its backing table.  The specified data source must use a non-XA JDBC driver since connection pools for XA JDBC drivers are not supported.

  An example on how to use this:

      wls_jdbc_persistence_store {a_wls_jdbc_persistence_store :
         ...
         data_source => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jdbc_persistence_store:data_source']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('DataSource')
end
