# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:deletes_per_statement_maximum, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum number of table rows that are deleted per database call.  <ul> <li> Applies only when a JDBC store does not use JDBC 3.0 batching to batch concurrent client requests. </li>  <li> The maximum deletes per statement has no effect on the maximum number of concurrent client requests. </li>  <li> For some databases, the JDBC store may choose a lower value than the one configured. </li> </ul>

  An example on how to use this:

      wls_jdbc_persistence_store {a_wls_jdbc_persistence_store :
         ...
         deletes_per_statement_maximum => '20'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jdbc_persistence_store:deletes_per_statement_maximum']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('DeletesPerStatementMaximum')
end
