# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:prefix_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The prefix for the JDBC store's database table (<code>WLStore</code>), in the following format: <code>[[[catalog.]schema.]prefix]</code>.  Each period symbol in the <code>[[catalog.]schema.]prefix</code> format is significant, where schema generally corresponds to username in many databases. When no prefix is specified, the JDBC store table name is simply <code>WLStore</code> and the database implicitly determines the schema according to the JDBC connection's user. As a best practice, you should always configure a prefix for the JDBC <code>WLStore</code> table name.  For specific guidelines about using JDBC store prefixes, refer to the "Using the WebLogic Store" section of Designing and Configuring WebLogic Server Environments".

  An example on how to use this:

      wls_jdbc_persistence_store {a_wls_jdbc_persistence_store :
         ...
         prefix_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jdbc_persistence_store:prefix_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('PrefixName')
end
