# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_jms_bridge_destination) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage a jms bridge destination in an WebLogic domain.

    Here is an example on how you should use this:

        wls_jms_bridge_destination { 'myBridgeDest':
          ensure                => 'present',
          adapter               => 'eis.jms.WLSConnectionFactoryJNDINoTX',
          classpath             => 'myClasspath',
          connectionfactoryjndi => 'myCFJndi',
          connectionurl         => 'myConnUrl',
          destinationjndi       => 'myDestJndi',
          destinationtype       => 'Queue',
          initialcontextfactory => 'weblogic.jndi.WLInitialContextFactory',
        }

    In this example you are managing a bridge destination in the default domain. When you want to
    manage a bridge destination in a specific domain, you can use:

        wls_jms_bridge_destination { 'my_domain/myBridgeDest':
          ensure                => 'present',
          adapter               => 'eis.jms.WLSConnectionFactoryJNDINoTX',
          classpath             => 'myClasspath',
          connectionfactoryjndi => 'myCFJndi',
          connectionurl         => 'myConnUrl',
          destinationjndi       => 'myDestJndi',
          destinationtype       => 'Queue',
          initialcontextfactory => 'weblogic.jndi.WLInitialContextFactory',
        }

    [Here](https://javamail.java.net/nonav/docs/api/) you can find more information about JMS bridge
    desitinations.

    DESC

    bean_type('JMSBridgeDestination')

    ensurable
    parameter :domain
    parameter :name
    parameter :bridge_destination_name

    property :adapter
    property :classpath
    property :connectionfactoryjndi
    property :connectionurl
    property :destinationjndi
    property :destinationtype
    property :initialcontextfactory
    property :user_name
    property :password
    extraproperties do
      property :adapter_jndi_name
      property :connection_factory_jndi_name
      property :destination_jndi_name
      property :destination_type
      property :initial_context_factory
      property :notes
      property :user_password
      #
      # Weblogic 12.2.1 new properties
      #
      property :connection_url
      property :tags
    end

    add_title_attributes(:bridge_destination_name)
  end
end
