# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:adapter_jndi_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The JNDI name of the adapter used to communicate with the specified destination.  This name is specified in the adapter's deployment descriptor file and is used by the WebLogic Server Connector container to bind the adapter in WebLogic Server JNDI.

  An example on how to use this:

      wls_jms_bridge_destination {a_wls_jms_bridge_destination :
         ...
         adapter_jndi_name => 'eis.jms.WLSConnectionFactoryJNDIXA'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_bridge_destination:adapter_jndi_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('AdapterJNDIName')
end
