# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:delivery_default_priority, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The default priority used for messages when a priority is not explicitly defined.  All messages with a DefaultPriority of -1 that are produced on a connection created with this factory will receive this value. Message producers can get the priority explicitly by calling the <code>javax.jms.MessageProducer.getPriority()</code> method.  This attribute is dynamic. It can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory.

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         delivery_default_priority => '4'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:delivery_default_priority']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('DefaultDeliveryParams/%<connection_factory_name>s/DefaultPriority')
end
