# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:local_jndi_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The local JNDI name used to look up the connection factory within the JNDI namespace of the server where the connection factory is targeted. In a clustered environment, this name is bound only on the local server instance and is not propagated to the rest of the cluster.  If not specified, then the connection factory is not bound into the local JNDI namespace.

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         local_jndi_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:local_jndi_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('LocalJNDIName')
end
