# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jms_create_destination_identifier, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  A reference name for a destination or a member of a distributed destination that provides a way to lookup that destination without JNDI using <code>javax.jms.Session createQueue </code> or <code>createTopic</code>. See "How to Lookup a Destination" in  Programming JMS for more information on how to use this attribute.  This name must be unique within the scope of the JMS server to which this destination is targeted. However, it does not need to be unique within the scope of an entire JMS module or WebLogic Cluster. For example, two queues can have the same destination name as long as those queues are targeted to different JMS servers.  Note: Since this name must be unique within the scope of a JMS server, verify whether other JMS modules may contain destination names that conflict with this name. It is the responsibility of the deployer to resolve the destination names targeted to JMS servers.

  An example on how to use this:

      wls_jms_queue {a_wls_jms_queue :
         ...
         jms_create_destination_identifier => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_queue:jms_create_destination_identifier']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JMSCreateDestinationIdentifier')
end
