# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:compatibility_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
   This is only set for beans created as a result of conversion from an 8.1 application configured using ApplicationMBean and ComponentMBean.  Standalone modules in 8.1 have both an ApplicationMBean name and ComponentMBean name. This attribute stores the name of the latter, to be used when the server creates the transient ComponentMBean for backward compatibility.

  An example on how to use this:

      wls_jms_subdeployment {a_wls_jms_subdeployment :
         ...
         compatibility_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_subdeployment:compatibility_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('CompatibilityName')
end
