# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:insertion_paused_at_startup, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Indicates whether insertion is paused at startup on destinations targeted to this JMS server. A destination cannot receive any new messages while it is paused.  When the value is set to <code>true</code>, then immediately after the host server instance is booted, then this JMS server and its targeted destinations are modified such that they are in a "insertion paused" state, which results preventing messages that are result of the "in-flight" work completion to arrive on those destinations.  Note: For a detailed definition of "in-flight" work/messages, see weblogic.management.runtime.JMSServerRuntimeMBean#resumeInsertion and weblogic.management.runtime.JMSDestinationRuntime#resumeInsertion  To allow in-flight work messages to appear on the destinations, later you will have to change the state of this JMS server to an "insertion enabled" state by setting this value to <code>false</code>, and then either redeploy the JMS server or reboot the hosting server instance.  When the value is set to <code>default</code>, then the Insertion Paused At Startup is determined based on the corresponding setting on the individual destination.

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         insertion_paused_at_startup => 'default'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:insertion_paused_at_startup']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('InsertionPausedAtStartup')
end
