# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_file_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The name of the file that stores current JMS server log messages. Usually it is a computed value based on the name of the parent of this MBean. For example, for a JMS server log, it is <code>jmsserverName.log</code>.  However, if the name of the parent cannot be obtained, the file name is <code>weblogic.log</code>. If you specify a relative pathname, it is interpreted as relative to the server's root directory.  To include a time and date stamp in the file name when the log file is rotated, add <code>java.text.SimpleDateFormat</code> variables to the file name. Surround each variable with percentage (<code>%</code>) characters.  For example, if the file name is defined to be <code>myjmsserver_%yyyy%_%MM%_%dd%_%hh%_%mm%.log</code>, the log file will be named <code>myserver_yyyy_mm_dd_hh_mm.log</code>.  When the log file is rotated, the rotated file name contains the date stamp. For example, if the log file is rotated on 2 April, 2005 at 10:05 AM, the log file that contains the old messages will be named <code>myserver_2005_04_02_10_05.log</code>.  If you do not include a time and date stamp, the rotated log files are numbered in order of creation. For example, <code>myjmsserver.log00007</code>.

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         log_file_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:log_file_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JMSMessageLogFile/%<jmsserver_name>s/FileName')
end
