# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_mail_session) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage a mail_session in an WebLogic domain.

    Here is an example on how you should use this:

        wls_mail_session { 'myMailSession':
          ensure         => 'present',
          jndiname       => 'myMailSession',
          target         => ['ManagedServer1', 'WebCluster'],
          targettype     => ['Server', 'Cluster'],
          mailproperty   => ['mail.host=smtp.hostname.com', 'mail.user=smtpadmin'],
        }

    In this example you are managing a mail session in the default domain. When you want to
    manage a mail session in a specific domain, you can use:

        wls_mail_session { 'my_domain/myMailSession':
          ensure         => 'present',
          jndiname       => 'myMailSession',
          target         => ['ManagedServer1', 'WebCluster'],
          targettype     => ['Server', 'Cluster'],
          mailproperty   => ['mail.host=smtp.hostname.com', 'mail.user=smtpadmin'],
        }

    DESC

    bean_type('MailSession')

    ensurable
    parameter :domain
    parameter :name
    parameter :mailsession_name
    parameter :timeout

    # Shared
    property :mailproperty
    property :jndiname
    property :target
    property :targettype
    extraproperties do
      property :deployment_order
      property :javamail_properties
      property :session_password
      property :jndi_name
      property :notes
      property :session_username
      #
      # Weblogic 12.2.1 new properties
      #
      property :extra_properties
      property :tags
    end

    add_title_attributes(:mailsession_name)
  end
end
