# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ds_failover_request_if_busy, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  For multi data sources with the <code>failover</code> algorithm, enables the multi data source to failover connection requests to the next data source if all connections in the current data source are in use.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         ds_failover_request_if_busy => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:ds_failover_request_if_busy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCDataSourceParams/%<multi_datasource_name>s/FailoverRequestIfBusy')
end
