# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_statement_cache_type, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The algorithm used for maintaining the prepared statements stored in the statement cache.  Options are: <ul> <li>LRU - when a new prepared or callable statement is used, the least recently used statement is replaced in the cache.</li> <li>FIXED - the first fixed number of prepared and callable statements are cached.</li> </ul>

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_statement_cache_type => 'LRU'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_statement_cache_type']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')
  data_type('Optional[String]')

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCConnectionPoolParams/%<multi_datasource_name>s/StatementCacheType')
end
