# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xa_need_tx_ctx_on_close, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether the XA driver requires a distributed transaction context when closing various JDBC objects (result sets, statements, connections, and so forth). Only applies to connection pools that use an XA driver.  When enabled, SQL exceptions that are thrown while closing the JDBC objects without a transaction context will be suppressed.  Use this setting to work around specific problems with JDBC XA drivers.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         xa_need_tx_ctx_on_close => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:xa_need_tx_ctx_on_close']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCXAParams/%<multi_datasource_name>s/NeedTxCtxOnClose')
end
