# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'easy_type/source_dir'

newparam(:source, :parent => EasyType::SourceDir) do
  defaultto ''
  isrequired

  def custom_action
    return if resource.patch_type == 'single'

    Puppet.debug 'Unzipping individual patch zips in spb patch.'
    #
    # If the patch is a spb patch, process all zips in the
    # zip before passing on
    #
    spb_patch_list.each { |p| unzip("#{spb_root}/#{p}", @value) }
  end

  def spb_root
    spb_patchlist_file.split("/#{spb_architecture}_patchlist.txt").first
  end

  def spb_patch_list
    File.read(spb_patchlist_file).split
  end

  def spb_patchlist_file
    found_files = Dir["#{@value}/**/binary_patches/#{spb_architecture}_patchlist.txt"]
    raise "SPB zip file doesn't contain file 'binary_patches/#{spb_architecture}_patchlist.txt'" if found_files.empty?
    raise "SPB zip file doesn't contains multile 'binary_patches/#{spb_architecture}_patchlist.txt'" if found_files.size > 1

    found_files.first
  end

  def spb_architecture
    kernel = Facter.value(:kernel)
    os_hardware = Facter.value(:os)['hardware']
    case kernel
    when 'Linux'
      case os_hardware
      when 'x86_64'
        'linux64'
      else
        fail "spb patching not (yet) supported on #{os_hardware}."
      end
    else
      fail "spb patching not (yet) supported on #{os_hardware}."
    end
  end
end
