# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'easy_type'
module Puppet
  Type.newtype(:wls_rcu) do
    def self.module_name
      'wls_config'
    end
    desc <<-DESC
    This is the Oracle WebLogic RCU ( Repository creation utility) installer type

    DESC
    # TODO: Add better and more documentation

    newproperty(:ensure) do
      include EasyType
      desc <<-DESC
    Whether a Repository should be created.

      DESC

      newvalue(:present, :event => :rcu_installed) do
        provider.present
      end

      newvalue(:absent, :event => :rcu_absent) do
        provider.absent
      end

      aliasvalue(:create, :present)
      aliasvalue(:delete, :absent)
      data_type("Optional[Enum['present','absent','create','delete']]")

      def retrieve
        provider.status
      end

      def sync
        event = super()
        # rubocop:disable all
        if property = @resource.property(:enable)
          val = property.retrieve
          property.sync unless property.safe_insync?(val)
        end
        # rubocop:enable all
        event
      end
    end

    newparam(:name) do
      include EasyType
      desc <<-DESC
        The prefix of the RCU.
      DESC
      data_type('Optional[String[1]]')
      isnamevar
    end

    newparam(:os_user) do
      include EasyType
      desc <<-DESC
        The weblogic operating system user.
      DESC
      data_type('Optional[String[1]]')
    end

    newparam(:sys_user) do
      include EasyType
      desc <<-DESC
        The sys user for the RCU check/install.
      DESC
      data_type('Optional[String[1]]')
    end

    newparam(:sys_password) do
      include EasyType
      desc <<-DESC
        The sys password for the RCU check/install.
      DESC
      data_type('Optional[String[1]]')
    end

    newparam(:jdbc_url) do
      include EasyType
      desc <<-DESC
        The jdbc url for the RCU check.
      DESC
      data_type('Optional[String[1]]')
    end

    newparam(:oracle_home) do
      include EasyType
      desc <<-DESC
        The oracle_home for the WLST location.
      DESC
      data_type('Optional[String[1]]')
    end

    newparam(:check_script) do
      include EasyType
      desc <<-DESC
        The check_script py script for the RCU Repository.
      DESC
      data_type('Optional[String[1]]')
    end

    newparam(:statement) do
      include EasyType
      desc <<-DESC
        The RCU statement.
      DESC
      data_type('Optional[String[1]]')
    end

    newparam(:jdk_home_dir) do
      include EasyType
      desc <<-DESC
        The jdk_home_dir.
      DESC
      data_type('Optional[String[1]]')
    end
  end
end
