# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:bytes_threshold_high, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The upper threshold value that triggers events based on the number of bytes stored in the SAF agent.  <ul> <li> The default value of <code>-1</code>  disables the events for this SAF agent.  </li>  <li> Applies only to agents with sending capability. </li>  <li> Updating <code>BytesThresholdHigh</code> affects only new requests. </li>  <li> If the number of bytes exceeds this threshold, the triggered events are:  <ul> <li>Log Messages: A message is logged on the server indicating a high threshold condition. </li>  <li>Flow Control: The agent becomes armed and instructs producers to begin decreasing their message flow. </li> </ul> </li> </ul>  Range of Values: &lt;= BytesMaximum; &gt;= BytesThresholdLow

  An example on how to use this:

      wls_safagent {a_wls_safagent :
         ...
         bytes_threshold_high => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_safagent:bytes_threshold_high']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('BytesThresholdHigh')
end
