# frozen_string_literal: true

newproperty(:auditor_types, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Returns the types of Auditing providers that may be created in this security realm, for example, <code>weblogic.security.providers.audit.DefaultAuditor</code>. Use this method to find the available types to pass to <code>createAuditor</code>

  An example on how to use this:

      wls_security_realm {a_wls_security_realm :
         ...
         auditor_types => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_security_realm:auditor_types']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('AuditorTypes')
end
