# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:complete_iiop_message_timeout, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum number of seconds spent waiting for a complete IIOP message to be received. This timeout helps guard against denial of service attacks in which a caller indicates that they will be sending a message of a certain size which they never finish sending.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         complete_iiop_message_timeout => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:complete_iiop_message_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('CompleteIIOPMessageTimeout')
end
