# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_rotate_log_on_startup, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether a server rotates its log file during its startup cycle. The default value in production mode is false.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         log_rotate_log_on_startup => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:log_rotate_log_on_startup']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('Log/%<server_name>s/RotateLogOnStartup')
end
