# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:overload_failure_action, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Enable automatic forceshutdown of the server on failed state. The server self-health monitoring detects fatal failures and mark the server as failed. The server can be restarted using NodeManager or a HA agent.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         overload_failure_action => 'no-action'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:overload_failure_action']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('OverloadProtection/%<server_name>s/FailureAction')
end
