# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ssl_identity_and_trust_locations, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Indicates where SSL should find the server's identity (certificate and private key) as well as the server's trust (trusted CAs).  <ul> <li> If set to <code>KEYSTORES</code>, then SSL retrieves the identity and trust from the server's keystores (that are configured on the Server). </li>  <li> If set to <code>FILES_OR_KEYSTORE_PROVIDERS</code>, then SSL first looks in the deprecated KeyStore providers for the identity and trust. If not found, then it looks in the flat files indicated by the SSL Trusted CA File Name, Server Certificate File Name, and Server Key File Name attributes. </li> </ul>  Domains created in WebLogic Server version 8.1 or later, default to <code>KEYSTORES</code>. Domains created before WebLogic Server version 8.1, default to <code>FILES_OR_KEYSTORE_PROVIDERS.</code>

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         ssl_identity_and_trust_locations => 'KeyStores'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:ssl_identity_and_trust_locations']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('SSL/%<server_name>s/IdentityAndTrustLocations')
end
