# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ssl_use_client_cert_for_outbound, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Determines whether to use the configured client SSL certificate as identity for outbound SSL connections. <p/> Note that to use a client SSL certificate, one must be specified in <code>{@link #setClientCertAlias}</code>.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         ssl_use_client_cert_for_outbound => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:ssl_use_client_cert_for_outbound']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('SSL/%<server_name>s/UseClientCertForOutbound')
end
