# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:transaction_log_file_prefix, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The path prefix for the server's JTA transaction log files. If the pathname is not absolute, the path is assumed to be relative to the server's root directory.  For a clustered server, if you plan to be able to migrate the Transaction Recovery Service from this server if it fails to another server (backup server) in the same cluster, you must store transaction log files on persistent storage, such as a Storage Area Network (SAN) device or a dual-ported disk, available to both servers.  Do not use an NFS file system to store transaction log files. Because of the caching scheme in NFS, transaction log files on disk may not always be current. Using transaction log files stored on an NFS device for recovery may cause data corruption.#{'  '}

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         transaction_log_file_prefix => './'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:transaction_log_file_prefix']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('TransactionLogFilePrefix')
end
