# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:use_enhanced_increment_advisor, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Whether the self-tuning should use the enhanced IncrementAdvisor implementation that uses a different algorithm to adjust the size of the self-tuning thread pool.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         use_enhanced_increment_advisor => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:use_enhanced_increment_advisor']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('UseEnhancedIncrementAdvisor')
end
