# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:webserver_keep_alive_secs, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-DESC
  The amount of time this server waits before closing an inactive HTTP connection.  Number of seconds to maintain HTTP keep-alive before timing out the request.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         webserver_keep_alive_secs => '30'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:webserver_keep_alive_secs']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('WebServer/%<server_name>s/KeepAliveSecs')
end
