# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:webserver_log_buffer_size_kb, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-DESC
  Gets the underlying log buffer size in kilobytes

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         webserver_log_buffer_size_kb => '8'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:webserver_log_buffer_size_kb']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('WebServer/%<server_name>s/WebServerLog/%<server_name>s/BufferSizeKB')
end
