# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:outbound_private_key_alias, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The string alias used to store and retrieve the outbound private key in the keystore. This private key is associated with either a server or a client digital certificate. This attribute value is derived from other settings and cannot be physically set.   The returned value is determined as follows: <ul> <li>If <code>{@link #isOutboundPrivateKeyEnabled}</code> and <code>{@link #isChannelIdentityCustomized}</code> return true, the value from <code>{@link #getCustomPrivateKeyAlias}</code> is returned. <li> Otherwise, the value from <code>{@link SSLMBean#getOutboundPrivateKeyAlias}</code> is returned from the <code>{@link ServerMBean}</code> for the channel. </ul>#{'  '}

  An example on how to use this:

      wls_server_channel {a_wls_server_channel :
         ...
         outbound_private_key_alias => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_channel:outbound_private_key_alias']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('OutboundPrivateKeyAlias')
end
