# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:complete_t3_message_timeout, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum number of seconds spent waiting for a complete T3 message to be received. If you configure network channels for this server, each channel can override this T3 message timeout.  This timeout helps guard against a denial of service attack in which a caller indicates that it will be sending a message of a certain size which it never finishes sending.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         complete_t3_message_timeout => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:complete_t3_message_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('CompleteT3MessageTimeout')
end
