# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jdbc_login_timeout_seconds, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The JDBC Login Timeout value. Specified value is passed into java.sql.DriverManager.setLoginTimeout(). Note that this DriverManager setting will impact *all* JDBC drivers loaded into this JVM. Feature is disabled by default.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         jdbc_login_timeout_seconds => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:jdbc_login_timeout_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('JDBCLoginTimeoutSeconds')
end
