# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jdbcllr_table_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The table name for this server's Logging Last Resource (LLR) database table(s). WebLogic Server creates the table(s) and then uses them during transaction processing for the LLR transaction optimization. This setting must be unique for each server. The default table name is <code>WL_LLR_SERVERNAME</code>.  This setting only applies if this server hosts one or more LLR-enabled JDBC data sources.  The format for the tables that WebLogic Server creates is [[[catalog.]schema.]name.] Each "." in the table name is significant, and schema generally corresponds to username in many databases.  IMPORTANT: If this value is changed but the LLR table already exists in the database, you must preserve the existing table's data. Consequently, when changing the table name, the existing database table must be renamed by a database administrator to match the new configured table name. Otherwise, transaction records may be lost, resulting in heuristic failures that aren't logged.  IMPORTANT: Each server's table name must be unique. Multiple LLR-enabled data sources within the same server may share the same table, but multiple servers must not share the same table. If multiple same-named servers share a table, the behavior is undefined and it is likely that transactions will not recover properly after a crash, creating heuristic hazards.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         jdbcllr_table_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:jdbcllr_table_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('JDBCLLRTableName')
end
