# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:listen_address, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The IP address or DNS name this server uses to listen for incoming connections.  Servers can be reached through the following URL:<br> protocol://listen-address:listen-port  Any network channel that you configure for this server can override this listen address.  If a server's listen address is undefined, clients can reach the server through an IP address of the computer that hosts the server, a DNS name that resolves to the host, or the localhost string. The localhost string can be used only for requests from clients that are running on the same computer as the server.  If you want to limit the valid addresses for a server instance, specify one of the following:  <ul> <li> IP address. If you provide an IP address, clients can specify either the IP address or a DNS name that maps to the IP address. Clients that specify an IP address and attempt to connect through an SSL port must disable hostname verification. </li>  <li> DNS name. If you provide a DNS name, clients can specify either the DNS name or the corresponding IP address. </li> </ul>  Do not leave the listen address undefined on a computer that uses multiple IP address (a multihomed computer). On such a computer, the server will bind to all available IP addresses.  <dl> <dt>Notes:</dt>  <dd> To resolve a DNS name to an IP address, WebLogic Server must be able to contact an appropriate DNS server or obtain the IP address mapping locally. Therefore, if you specify a DNS name for the listen address, you must either leave a port open long enough for the WebLogic Server instance to connect to a DNS server and cache its mapping or you must specify the IP address mapping in a local file. If you specify an IP address for ListenAddress and then a client request specifies a DNS name, WebLogic Server will attempt to resolve the DNS name, but if it cannot access DNS name mapping, the request fails. Note also that if you are using the demo certificates in a multi-server domain, Managed Server instances will fail to boot if you specify the fully-qualified DNS name. For information about this limitation and suggested workarounds, see "Limitation on CertGen Usage" in Administering Security for Oracle WebLogic Server. </dd> </dl>

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         listen_address => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:listen_address']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('ListenAddress')
end
