# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_rotation_type, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Criteria for moving old log messages to a separate file. <ul> <li><code>NONE</code> Messages accumulate in a single file. You must erase the contents of the file when the size is too large. Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.  <li><code>SIZE</code> When the log file reaches the size that you specify in <code>FileMinSize</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>.  <li><code>TIME</code> At each time interval that you specify in <code>TimeSpan</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>. </ul>  After the server renames a file, subsequent messages accumulate in a new file with the name that you specified as the log file name.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         log_rotation_type => 'bySize'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:log_rotation_type']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('Log/%<template_name>s/RotationType')
end
