# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:low_memory_granularity_level, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The granularity level (in percent) that this server uses for logging low memory conditions and changing the server health state to <tt>Warning</tt>.  For example, if you specify 5 and the average free memory drops by 5% or more over two measured intervals, the server logs a low memory warning in the log file and changes the server health state to <tt>Warning</tt>.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         low_memory_granularity_level => '5'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:low_memory_granularity_level']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('LowMemoryGranularityLevel')
end
