# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:managed_server_independence_enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether this Managed Server can be started when the Administration Server is unavailable.  In such a case, the Managed Server retrieves its configuration by reading a configuration file and other files directly.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         managed_server_independence_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:managed_server_independence_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('ManagedServerIndependenceEnabled')
end
