# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ssl_inbound_certificate_validation, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Indicates the client certificate validation rules for inbound SSL.  This attribute only applies to ports and network channels using 2-way SSL.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         ssl_inbound_certificate_validation => 'BuiltinSSLValidationOnly'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:ssl_inbound_certificate_validation']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('SSL/%<template_name>s/InboundCertificateValidation')
end
