# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_setting) do
    include EasyType::YamlType

    config_file '/etc/wls_setting.yaml'

    desc <<-DESC
    This resource allows you to set the defaults for all other wls types.


    All wls types needs a `wls_setting` definition. This is a pointer to an WebLogic AdminServer and
    you need to create one for every WebLogic domain. When you don't provide a `wls_setting` identifier
    in the title of the weblogic type then it will use `default` as identifier.

    Here is an example on how to create the `default` settings:

        wls_setting { 'default':
          user               => 'oracle',
          weblogic_home_dir  => '/opt/oracle/middleware11g/wlserver_10.3',
          connect_url        => "t3://localhost:7001",
          weblogic_user      => 'weblogic',
          weblogic_password  => 'weblogic1',
        }

    When you want to create an other domain, like for instance `domain2`. You use `wls_setting like this:

        wls_setting { 'domain2':
          user               => 'oracle',
          weblogic_home_dir  => '/opt/oracle/middleware11g/wlserver_10.3',
          connect_url        => "t3://localhost:7011",
          weblogic_user      => 'weblogic',
          weblogic_password  => 'weblogic1',
          post_classpath     => '/opt/oracle/wlsdomains/domains/Wls1036/lib/aa.jar',
          extra_properties   => ['wls_server:.*'],
        }

    DESC

    parameter :name
    property :user
    property :weblogic_home_dir
    property :weblogic_user
    property :connect_url
    property :weblogic_password
    property :post_classpath
    property :debug_module
    property :archive_path
    property :extra_properties
    property :custom_trust
    property :trust_keystore_file
    property :trust_keystore_passphrase
  end
end
