# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:overload_response_code, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Get the response code to be used when an application is overloaded. An application can get overloaded when the number of pending requests has reached the max capacity specified in the WorkManager or when the server is low on memory. The low memory condition is determined using {@link OverloadProtectionMBean#getFreeMemoryPercentLowThreshold()}.

  An example on how to use this:

      wls_virtual_host {a_wls_virtual_host :
         ...
         overload_response_code => '503'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_virtual_host:overload_response_code']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('OverloadResponseCode')
end
